
body {
	font-family: $font-family-sans-serif;
	font-weight: 400;
	font-size: 14px;
	color: #555;
	position: relative;
	&:before {
		content: "";
		position: absolute;
		top: 0;
		left: 0;
		right: 0;
		bottom: 0;
		background: rgba($black, .2);
		transition: .3s all ease;
		opacity: 0;
		visibility: hidden;
		z-index: 999;
	}

	&.offcanvas-menu {
		&:before {
			opacity: 1;
			visibility: visible;
		}
	}
}
h1, h2, h3, h4, h5, .logo {
	font-family: $font-family-sans-serif-secondary;
	color: $secondary;
}
a {
	transition: .3s all ease;
	text-decoration: none;
}

.btn {
	padding-top: 10px;
	padding-bottom: 10px;
	padding-left: 30px;
	padding-right: 30px;
	border-radius: 30px;
	color: $white;
	font-size: 15px;
	&:hover {
		color: $white;
	}
	&:focus, &:active {
		outline: none;
		box-shadow: none!important;
	}

	&.btn-outline-white {
		border-color :$white;
		color: $white;
		&:hover {
			background-color: $white;
			color: $primary;
		}
	}
}

.form-control, .custom-select {
	border: none;
	font-size: 16px;
	height: 45px;
  // padding-left: 0;
  // padding-right: 0;
  background: transparent;
  border: 1px solid lighten($dark, 5%);
  border-radius: 0;
  color: $black;
  &:active, &:focus {
  	color: $black;
  	border-color: $primary;
  	box-shadow: none;
  	background: transparent;
  }

  &::-webkit-input-placeholder { /* Chrome/Opera/Safari */
  	color: rgba($black, .5);
  }
  &::-moz-placeholder { /* Firefox 19+ */
  	color: rgba($black, .5);
  }
  &:-ms-input-placeholder { /* IE 10+ */
  	color: rgba($black, .5);
  }
  &:-moz-placeholder { /* Firefox 18- */
  	color: rgba($black, .5);
  }
}
textarea {
	height: auto!important;
}


// PRELOADER STYLE
#overlayer {
	width:100%;
	height:100%;  
	position:fixed;
	z-index:7100;
	background: $white;
	top: 0;
	left: 0;
	right: 0;
	bottom: 0;
}

.loader {
	z-index:7700;
	position: fixed;
	top: 50%;
	left: 50%;
	transform: translate(-50%, -50%);
}